<?php
/**
 * @file
 * Admin settings.
 */

/**
 *
 */
function set_front_page_config_form($form, &$form_state) {
  $front_page = variable_get('site_frontpage', '');
  $front_page_alias = url($front_page);
  $front_page_url = url($front_page, array('absolute' => TRUE));
  $form['site_frontpage'] = array(
    '#type' => 'textfield',
    '#title' => t("Site's current front page"),
    '#field_prefix' => t('Internal path:') . ' ',
    '#field_suffix' => '<br />'
      . t('Page alias: @url', array('@url' => $front_page_alias)) . '<br />'
      . t('Full URL: !url', array('!url' => l($front_page_url, $front_page_url))),
    '#default_value' => $front_page,
    '#required' => TRUE,
  );

  $default = variable_get('set_front_page_default', '');
  $form['set_front_page_default'] = array(
    '#type' => 'textfield',
    '#title' => t('Default front page (optional)'),
    '#description' => t('If provided, each page will have an extra option allowing the front page to be reassigned to this default page instead.'),
    '#field_prefix' => t('Internal path:') . ' ',
    '#default_value' => $default,
  );
  if (!empty($default)) {
    $default_alias = url($default);
    $default_url = url($default, array('absolute' => TRUE));
    $form['set_front_page_default']['#field_suffix'] = '<br />'
      . t('Path alias: @url', array('@url' => $default_alias)) . '<br />'
      . t('Full URL: !url', array('!url' => l($default_url, $default_url)));
  }

  $form['_prefix'] = array(
    '#markup' => t('Select which types of site content should be allowed to be used as the homepage.'),
    '#prefix' => '<p>',
    '#suffix' => '</p>',
  );

  foreach (entity_get_info() as $entity_type => $entity_info) {
    if (in_array($entity_type, array('node', 'taxonomy_term'))) {
      $form[$entity_type] = array(
        '#type' => 'container',
        '#tree' => FALSE,
      );
      $form[$entity_type]['_prefix'] = array(
        '#markup' => t($entity_info['bundle label']),
        '#prefix' => '<h4>',
        '#suffix' => '</h4>',
      );
      foreach ($entity_info['bundles'] as $bundle => $bundle_info) {
        $variable_name = 'set_front_page_' . $entity_type . '__' . $bundle;
        $form[$entity_type][$variable_name] = array(
          '#type' => 'checkbox',
          '#title' => t($bundle_info['label']),
          '#default_value' => variable_get($variable_name, FALSE),
        );
      }
    }
  }

  return system_settings_form($form);
}
